Description Usage Arguments Examples
Wrapper for save() and readr::write_csv() that
saves a RData or csv with today's date appended to filename
1 | save_date(object, path)
|
object |
the name of the object to be saved |
path |
the path of the data as you would normally provide it to |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.