Description Usage Arguments Examples
View source: R/load-most-recent.R
Wrapper for load() and readr::read_csv() that
saves a RData or csv with today's date appended to filename
1 | load_most_recent(directory, filename_keyword = NULL, date_in_filename = TRUE)
|
directory |
directory to look for most recent data files in |
filename_keyword |
a file name (e.g. "data.RData") or keyword (e.g. "patient-data"). If provided, function will only consider files in that directory with that name or keyword |
date_in_filename |
If |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.